@@ -7,6 +7,7 @@
 import time
 import sys
 import os
+
 from fast_tracker import config
 
 
@@ -20,8 +21,7 @@ def lower_case_name(text):
     for index, char in enumerate(text):
         if char.isupper() and index != 0:
             lst.append("_")
-        if char != ".":
-            lst.append(char)
+        lst.append(char)
 
     return "".join(lst).lower()
 
@@ -34,19 +34,10 @@ def log(text, *args, level=1):
     :param int level: 日志级别, 数字越高，打印信息越多，为0表示不打印日志。暂定级别有：0，1，2，3，4 可对应为logging的日志级别
     :return:
     """
-    if config.get_logging_level() != "ERROR":
+    startup_debug = config.debug
+    debug_level = config.debug_level
+    if startup_debug and debug_level >= level:
         text = text % args
         timestamp = time.strftime("%Y-%m-%d %H:%M:%S", time.localtime())
-        sys.stdout.write("FAST: %s - %s\n" % (timestamp, text))
+        sys.stdout.write("FAST: %s (%d) - %s\n" % (timestamp, os.getpid(), text))
         sys.stdout.flush()
-
-
-def getUri(text):
-    if "http://" in text:
-        index = text.find("//")
-        domain = text[index + 2:]
-        index = domain.find("/")
-        return domain[index:]
-    else:
-        index = text.find("/")
-    return text[index:]
